# ULiege-Latex - Customization packages for Latex classes

This repository contains various packages that can be used alongside well-known
latex classes. These packages implement specific customizations for the layout,
colors, etc that fit (or approach) the official ULiege graphical guidelines.

**None of these packages are officially endorsed by the University**. They were
just implemented in order to support my own material (presentation, thesis,
reports, etc), produced during my Ph.D. Thesis and Teaching Assistant mandate.

As these packages are meant to be used within the institution only, there is no
need to publish them officially on CTAN. The only way to get them is through
this repository (see Installation).

## Package list

### ULiege-colors

This package implements the official color palette of the University of Liège.
The full palette is available in RGB, HTML or CYMK conventions.

**Important**: This package is a dependency for all other packages, therefore it
must always be present in your system/project directory before trying to using
the other packages.

### ULiege-trigon

This package customizes the [Trigon theme for
Beamer](https://www.gitlab.com/thlamb/beamertheme-trigon) in order to follow the
ULiège style recommendations. Its main purpose is to pick the right color
palette and logos for the different faculties of the University.

The Trigon theme is available directly on
[CTAN](https://ctan.org/pkg/beamertheme-trigon). The source code of this theme
is on my [personal gitlab
repository](https://www.gitlab.com/thlamb/beamertheme-trigon), under the free
software license CC-BY-SA 4.0.  Trigon has been integrated in TexLive in April
2021, therefore it should be readily available on all new installations of
Latex (if not, just update your system and install the package through your
package manager).

### ULiege-KOMAthesis

This package customizes the `scrbook` document class (provided by the
[KOMA-script](https://www.ctan.org/tex-archive/macros/latex/contrib/koma-script)
package) in order to make nice looking, modern thesis. This package is largly
inspired by the excellent [cleanthesis package](http://cleanthesis.der-ric.de/)
by Ricardo Langner.

_As the graphical guidelines of the University do not explicitly mention theses,
some compromises regarding the exact graphical guidelines were made (fonts,
headers, margins,...). Moreover, I do not really feel that these guidelines are
really approriate for long scientific documents anyway (such as theses). If I
have some spare time at some point, I may check with the communication
department how to improve the style to match closely the official guidelines.
But this is not a priority as of today._

### To be determined

I also plan to create the following packages if I find some free time (or when I
will need them):

- Short reports (based on scrreprt)
- Long reports (based on scrreprt, very similar to ULiege-KOMAthesis)
- Posters (no idea yet)
- Letters (based on scrlttr2)

## Installation

The proper installation procedure is still to do.

For now, just copy the content of this repository (the `*.sty`files and than
`images/` folder) in the root of your latex project and just use the package as
any other one

```latex
\usepackage{uliege-colors}
\usepackage{uliege-trigon}
```

## Documentation

The complete documentation for these packages is not written yet. This section
is a very short summary.

### ULiege-colors

Simply load the package. You can then use the custom colors as you would for any
regular color

```latex
\usepackage{uliege-colors}
\begin{document}
\color{ulgBlueGreen}{This text is in Blue-Green}, the official color of the
Univeristy; while \color{ulgOrange}{This text is in Orange}, the official color
of the applied sciences faculty.
\end{document}
```

For all the color names (and their attribution), refer to the content of
`Uliege-colors.sty`.

### ULiege-trigon

In a beamer document using the Trigon class, load the package as follows

```latex
\usepackage[faculty=XXX,titlelogo=YYY,slidelogo=ZZZ]{uliege-trigon}
```

Where

- `XXX` is used to customize the color theme and can
  be one of the following:
  - uliege: ULiege style (default)
  - ssoc: Social sciences
  - apps: Applied sciences
  - med: Medicine
  - agro: Agro-Bio Tech
  - gemb: Gembloux agro-bio tech
  - psy: Psychology
  - phi: Philosophy
  - sci: Sciences
  - vet: Veterinary medicine
  - law: Law
  - hec: HEC (Management School)
  - arch: Architecture

- `YYY` is the logo to use on the titleslide. Three values are possible:
  - none: no logo on titleslide
  - uliege: ULiege logo
  - fac: (default) Faculty logo (as defined with faculty=XXX)

- `ZZZ` is the logo to use for the regular slides. The three same options are
  possible for the `slidelogo`:
  - none: no logo on content slides
  - uliege: ULiege logo
  - fac: (default) Faculty logo (as defined with faculty=XXX)

If nothing is mentioned, the default values are applied. Note that some
faculties do not have a custom `slidelogo` (the "U" with the triangles colored
following the faculty theme). In that case, the `uliege` logo will be used
by default, even though you specified `slidelogo=fac`.

## License

Copyright 2021 by Thomas Lambert <t.lambert@uliege.be>.

**Author and maintainer**: Thomas Lambert.

All these packages are licensed under the [Creative Commons
Attribution-ShareAlike 4.0 International
License](https://creativecommons.org/licenses/by-sa/4.0/), which is essentially
a _free software_ license. Do not hesitate to copy and modify the code to fit
your needs.

If you encounter some issues or have ideas/feature requests, do not hesitate to
contact me or use the issue tracker.
